'use client';

import React, { useCallback, useState } from 'react';
import { Select } from 'antd';
import { AdditionalFilter } from '../../types/experts';
import { INITIAL_ADD_FILTER } from '../../constants/experts';
import { LOCALES } from '../../constants/locale';
import { CustomInput } from '../view';

export const ExpertsAdditionalFilter = () => {
    const [filter, setFilter] = useState<AdditionalFilter>(INITIAL_ADD_FILTER);

    const onChangeFilter = useCallback((key: string, value: any) => {
        setFilter({
            ...filter,
            [key]: value
        })
    }, [filter]);

    return (
        <div className="main-find__search">
            <div className="main-find__search__input">
                <CustomInput
                    placeholder="Search for an Expert"
                    onChange={(e: any) => onChangeFilter('text', e?.target?.value)}
                />
            </div>
            <div className="main-find__search__sort">
                <Select
                    defaultValue={INITIAL_ADD_FILTER.sort}
                    onChange={(val) => onChangeFilter('sort', val)}
                    options={[
                        { value: 'By top views', label: 'By top views' },
                        { value: 'By Price Ascending', label: 'By Price Ascending' },
                        { value: 'By Price Descending', label: 'By Price Descending' },
                        { value: 'By rating', label: 'By rating' }
                    ]}
                />
            </div>
            <div className="main-find__search__language">
                <Select
                    mode="multiple"
                    defaultValue={INITIAL_ADD_FILTER.language}
                    onChange={(val) => onChangeFilter('language', val)}
                    options={Object.entries(LOCALES).map(([ value, label ]) => ({ value, label }))}
                />
            </div>
            <button className="btn-apply">Find</button>
        </div>
    );
};
