'use client';

import React, { useCallback, useState } from 'react';
import { List } from 'antd';
import { FilterType, INITIAL_FILTER } from '../../constants/experts';
import { Filter } from '../../types/experts';
import { CustomSwitch, CustomSlider } from '../view';
import {Locale} from "../../types/locale";

const dataCoaching = [
    {
        key: FilterType.WorkLifeBalance,
        title: 'Work-life Balance'
    },
    {
        key: FilterType.StrategicSession,
        title: 'Strategic Session'
    },
    {
        key: FilterType.PersonalGrowth,
        title: 'Personal Growth'
    },
    {
        key: FilterType.PersonalGrowth,
        title: 'Career Planning'
    },
    {
        key: FilterType.ExecutiveCoaching,
        title: 'Executive Coaching'
    }
];

const dataMentoring = [
    {
        key: FilterType.CareerDevelopment,
        title: 'Career Development'
    },
    {
        key: FilterType.Networking,
        title: 'Networking'
    }
];

const dataConsultation = [
    {
        key: FilterType.BusinessModelReview,
        title: 'Business Model Review'
    }
];

export const ExpertsFilter = ({ locale }: { locale: string }) => {
    const [filter, setFilter] = useState<Filter>(INITIAL_FILTER);
    const isRus = locale === Locale.ru;

    const onChangeFilter = useCallback((key: string, value: any) => {
        setFilter({
            ...filter,
            [key]: value
        })
    }, [filter]);

    const getList = useCallback((data: any[]) => (
        <div className="b-filter__inner">
            <List
                itemLayout="vertical"
                size="small"
                dataSource={data}
                split={false}
                style={{ width: '100%' }}
                renderItem={({ key, title }) => (
                    <List.Item key={key} style={{ padding: 0 }}>
                        <div className="b-filter__item">
                            <div className="b-filter__title">{title}</div>
                            <CustomSwitch
                                defaultChecked={filter[key]}
                                onChange={(checked: boolean) => onChangeFilter(key, checked)}
                            />
                        </div>
                    </List.Item>
                )}
            />
        </div>
    ), [filter]);

    return (
        <div className="b-filter">
            <h3 className="title-h3">Coaching</h3>
            {getList(dataCoaching)}
            <h3 className="title-h3">Mentoring</h3>
            {getList(dataMentoring)}
            <h3 className="title-h3">Business-consultation</h3>
            {getList(dataConsultation)}
            <h3 className="title-h3">{`Price from 45${isRus ? '₽' : '€'} to 170${isRus ? '₽' : '€'}`}</h3>
            <div className="b-filter__slider">
                <CustomSlider
                    range
                    step={1}
                    defaultValue={INITIAL_FILTER[FilterType.Price]}
                    min={45}
                    max={170}
                    onChange={(val: any) => onChangeFilter(FilterType.Price, val)}
                />
            </div>
            <h3 className="title-h3">{`Duration from 45${isRus ? 'мин' : 'min'} to 120${isRus ? 'мин' : 'min'}`}</h3>
            <div className="b-filter__slider">
                <CustomSlider
                    range
                    step={1}
                    defaultValue={INITIAL_FILTER[FilterType.Duration]}
                    min={45}
                    max={120}
                    onChange={(val: any) => onChangeFilter(FilterType.Duration, val)}
                />
            </div>
            <button className="btn-apply">Apply</button>
        </div>
    );
};
